reset_current_tool_state

Function reset_current_tool_state 

pub fn reset_current_tool_state(
    buffer: &mut String,
    current_tool_name_sent: &mut bool,
    streamed_args_for_tool: &mut Vec<String>,
    prev_tool_call_arr: &[Value],
)
Reset state for the current tool being parsed (used when skipping invalid tools). This preserves the parser’s overall state (current_tool_id, prev_tool_call_arr) but clears the state specific to the current incomplete tool.