Passthrough parser that returns text unchanged
This parser is used as a fallback for unknown models where no specific tool call parsing should be performed. It simply returns the input text with no tool calls detected.
Passthrough parser that returns text unchanged
This parser is used as a fallback for unknown models where no specific tool call parsing should be performed. It simply returns the input text with no tool calls detected.